Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2054)

Unified Diff: chrome/browser/task_management/providers/task_provider.h

Issue 1584473004: Migrate ProcessesEventRouter to the new task manager (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix nit. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/task_management/providers/task_provider.h
diff --git a/chrome/browser/task_management/providers/task_provider.h b/chrome/browser/task_management/providers/task_provider.h
index e4387cf65b1ca474dea9ed093aa299bf760ab54e..545e9a197ad3f1b97d5a879cc276f312afaf45ed 100644
--- a/chrome/browser/task_management/providers/task_provider.h
+++ b/chrome/browser/task_management/providers/task_provider.h
@@ -45,10 +45,11 @@ class TaskProvider {
protected:
// Used by concrete task providers to notify the observer of tasks addition/
// removal. These methods should only be called after StartUpdating() has been
// called and before StopUpdating() is called.
void NotifyObserverTaskAdded(Task* task) const;
void NotifyObserverTaskRemoved(Task* task) const;
+ void NotifyObserverTaskUnresponsive(Task* task) const;
private:
// This will be called once an observer is set for this provider. When it is
« no previous file with comments | « chrome/browser/task_management/providers/task.cc ('k') | chrome/browser/task_management/providers/task_provider.cc » ('j') | no next file with comments »
@@ -45,10 +45,11 @@ class TaskProvider {
protected:
// Used by concrete task providers to notify the observer of tasks addition/
- // removal. These methods should only be called after StartUpdating() has been
- // called and before StopUpdating() is called.
+ // removal/renderer unresponsive. These methods should only be called after
+ // StartUpdating() has been called and before StopUpdating() is called.
void NotifyObserverTaskAdded(Task* task) const;
void NotifyObserverTaskRemoved(Task* task) const;

Powered by Google App Engine
This is Rietveld 408576698